@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyBrowser.h 8176 2008-03-31 21:55:14Z chpe $
+ *  $Id$
  */
 
 #ifndef EPHY_BROWSER_H
@@ -37,6 +37,7 @@
 #include <nsIWebBrowser.h>
 #include <nsIWebNavigation.h>
 #include <nsPIDOMWindow.h>
+#include <nsIURIFixup.h>
 
 #ifdef ALLOW_PRIVATE_API
 #include <nsIContentViewer.h>
@@ -207,6 +208,7 @@ public:
 	nsCOMPtr<nsIWebBrowser> mWebBrowser;
 private:
 	GtkWidget *mEmbed;
+	float mZoom;
 
 	nsCOMPtr<nsIWebBrowserFocus> mWebBrowserFocus;
 	nsCOMPtr<nsIDOMDocument> mTargetDocument;
@@ -225,6 +227,7 @@ private:
 #ifdef HAVE_MOZILLA_PSM
 	nsCOMPtr<nsISecureBrowserUI> mSecurityInfo;
 #endif
+        nsCOMPtr<nsIURIFixup> mFixup;
 
 	nsresult GetListener (void);
 	nsresult AttachListeners (void);
