@@ -16,14 +16,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-shell.c 7695 2007-11-16 15:03:10Z xan $
+ *  $Id$
  */
 
 #include "config.h"
 
 #include <string.h>
 #include <glib/gi18n.h>
-#include <gtk/gtknotebook.h>
+#include <gtk/gtk.h>
 #include <dirent.h>
 #include <unistd.h>
 
@@ -90,35 +90,7 @@ static void ephy_shell_dispose		(GObject *object);
 static void ephy_shell_finalize		(GObject *object);
 static GObject *impl_get_embed_single   (EphyEmbedShell *embed_shell);
 
-static GObjectClass *parent_class;
-
-GType
-ephy_shell_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo our_info =
-		{
-			sizeof (EphyShellClass),
-			NULL, /* base_init */
-			NULL, /* base_finalize */
-			(GClassInitFunc) ephy_shell_class_init,
-			NULL,
-			NULL, /* class_data */
-			sizeof (EphyShell),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) ephy_shell_init
-		};
-
-		type = g_type_register_static (EPHY_TYPE_EMBED_SHELL,
-					       "EphyShell",
-					       &our_info, 0);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE (EphyShell, ephy_shell, EPHY_TYPE_EMBED_SHELL)
 
 static void
 ephy_shell_class_init (EphyShellClass *klass)
@@ -126,8 +98,6 @@ ephy_shell_class_init (EphyShellClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 	EphyEmbedShellClass *embed_shell_class = EPHY_EMBED_SHELL_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class->dispose = ephy_shell_dispose;
 	object_class->finalize = ephy_shell_finalize;
 
@@ -241,7 +211,7 @@ impl_get_embed_single (EphyEmbedShell *embed_shell)
 	EphyShellPrivate *priv = shell->priv;
 	GObject *embed_single;
 
-	embed_single = EPHY_EMBED_SHELL_CLASS (parent_class)->get_embed_single (embed_shell);
+	embed_single = EPHY_EMBED_SHELL_CLASS (ephy_shell_parent_class)->get_embed_single (embed_shell);
 
 	if (embed_single != NULL &&
 	    priv->embed_single_connected == FALSE)
@@ -370,13 +340,13 @@ ephy_shell_dispose (GObject *object)
 	}
 #endif /* ENABLE_NETWORK_MANAGER */
 
-	G_OBJECT_CLASS (parent_class)->dispose (object);
+	G_OBJECT_CLASS (ephy_shell_parent_class)->dispose (object);
 }
 
 static void
 ephy_shell_finalize (GObject *object)
 {
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (ephy_shell_parent_class)->finalize (object);
 
 	LOG ("Ephy shell finalised");
 }
@@ -450,7 +420,7 @@ load_homepage (EphyEmbed *embed)
 EphyEmbed *
 ephy_shell_new_tab_full (EphyShell *shell,
 			 EphyWindow *parent_window,
-			 EphyEmbed *previous_tab,
+			 EphyEmbed *previous_embed,
 			 const char *url,
 			 EphyNewTabFlags flags,
 			 EphyEmbedChrome chrome,
@@ -458,10 +428,10 @@ ephy_shell_new_tab_full (EphyShell *shell,
 			 guint32 user_time)
 {
 	EphyWindow *window;
-	EphyEmbed *embed;
+	EphyEmbed *embed = NULL;
 	gboolean in_new_window = TRUE;
 	gboolean jump_to;
-	EphyEmbed *previous_embed = NULL;
+	gboolean active_is_blank = FALSE;
 	GtkWidget *nb;
 	int position = -1;
 	gboolean is_empty = FALSE;
@@ -489,28 +459,43 @@ ephy_shell_new_tab_full (EphyShell *shell,
 
 	toolbar = EPHY_TOOLBAR (ephy_window_get_toolbar (window));
 
-	if ((flags & EPHY_NEW_TAB_APPEND_AFTER) && previous_tab != NULL)
+	if ((flags & EPHY_NEW_TAB_APPEND_AFTER) && previous_embed != NULL)
 	{
 		nb = ephy_window_get_notebook (window);
                 /* FIXME this assumes the tab is the direct notebook child */
 		position = gtk_notebook_page_num (GTK_NOTEBOOK (nb),
 						  GTK_WIDGET (previous_embed)) + 1;
 	}
-
-	embed = EPHY_EMBED (ephy_embed_factory_new_object (EPHY_TYPE_EMBED));
-	g_assert (embed != NULL);
-	gtk_widget_show (GTK_WIDGET (embed));
-
-	ephy_embed_container_add_child (EPHY_EMBED_CONTAINER (window), embed, position, jump_to);
+	
+	if (flags & EPHY_NEW_TAB_FROM_EXTERNAL)
+	{
+		/* If the active embed is blank, use that to open the url and jump to it */
+		embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
+		if (embed != NULL)
+		{
+			if (ephy_embed_get_is_blank (embed))
+			{
+				active_is_blank = TRUE;
+			}
+		}
+	}
+	if (active_is_blank == FALSE)
+	{
+		embed = EPHY_EMBED (ephy_embed_factory_new_object (EPHY_TYPE_EMBED));
+		g_assert (embed != NULL);
+		gtk_widget_show (GTK_WIDGET (embed));
+		
+		ephy_embed_container_add_child (EPHY_EMBED_CONTAINER (window), embed, position, jump_to);
+	}
 
 	if (previous_embed != NULL)
-	{
+	{	
 		ephy_embed_shistory_copy (previous_embed,
 					  embed,
 					  TRUE,   /* back history */
 					  TRUE,   /* forward history */
 					  FALSE); /* current index */
-	}
+	}		
 
 	ephy_gui_window_update_user_time (GTK_WIDGET (window), user_time);
 
